module.exports = (function() {
  "use strict";

  var Promise = require("bluebird");
  var fs = require("fs");

  var checkForTrailingNewLine = function(sourceFile, output) {
    return new Promise(function(resolve, reject) {
      // Get file stats, including size.
      fs.stat(sourceFile, function(err, stat) {
        if (err) {
          return reject(err);
        }
        output.debug("%s file size is %d",sourceFile, stat.size);
        // Open the file for reading.
        fs.open(sourceFile, "r", function(err, fd) {
            if (err) {
              reject(new Error("failed to open source file: " + err.message));
            }
            var buf = new Buffer(1);
            output.debug("reading at position %d",stat.size-buf.length);
            fs.read(fd, buf, 0, buf.length, stat.size-buf.length, function(err, bytesRead, buffer) {
              if(err) {
                reject(err);
              }
              output.debug("last byte in file is %d",buffer[0]);
              fs.close(fd, function(err) {
                if (err) {
                  return reject(err);
                }
                if (buffer[0] !== 0x0a) { 
                  output.debug("no trailing new line - adding one");
                  fs.appendFile(sourceFile, "\n", function (err) {
                    if (err) {
                      output.debug("failed to append new line");
                      return reject(err);
                    } else {
                      return resolve();
                    }
                  });
                } else {                    
                  // There is a trailing new line - nothing to do.
                  return resolve();
                }
              });
            });
        });
      });
    });
  };

  return checkForTrailingNewLine;
}());