module.exports = (function() {
  "use strict";

  var Promise = require("bluebird");
  var fs = require("fs");
  var split = require("split");

  var convertor = function(source, target, output) {
    return new Promise(function(resolve, reject) {
      var targetStream = fs.createWriteStream(target);
      
      var errorHandler = function(err) {
        output.debug("failure during JSON parse: %s", err.message);
        reject(err);
      };

      var reader = fs.createReadStream(source, { encoding: "utf8" });
      reader.on("error", errorHandler); 

      reader.pipe(split(JSON.parse, null, {trailing: false}))
        .on("data", function (doc) {
          if (doc) {
            // Add event parameters and write to event store database source file.
            doc.__event = "created";
            doc.__timestamp = Date.now();
            doc.__version = 1;
            targetStream.write(JSON.stringify(doc) + "\n","utf8");
          }
        })
        .on("end", resolve)
        .on("error", errorHandler);
    });
  };

  return convertor;

}());