module.exports = (function() {
  "use strict";

  var Promise = require("bluebird");
  var fs = require("fs");
  var JSONStream = require("JSONStream");
  var es = require("event-stream");

  var reformat = function(parsePath, source, targetRead, targetES) {
    return new Promise(function(resolve, reject) {
      var targetStream = fs.createWriteStream(targetRead);
      var esTargetStream = fs.createWriteStream(targetES);
      
      var writeDocument = function(doc) {
        if (doc) {
          // Write source document direct to read database source file.
          targetStream.write(JSON.stringify(doc) + "\n", "utf8");

          // Add event parameters and write to event store database source file.
          doc.__event = "created";
          doc.__timestamp = Date.now();
          doc.__version = 1;
          esTargetStream.write(JSON.stringify(doc) + "\n","utf8");
        }
      };

      var errorHandler = function(err) {
        output.debug("failure during JSON reformatting: %s", err.message);
        reject(err);
      };

      var reader = fs.createReadStream(source, { encoding: "utf8" });
      reader.on("error", errorHandler); 

      var jsonParser = JSONStream.parse(parsePath);
      jsonParser.on("error", errorHandler);

      reader.pipe(jsonParser).pipe(es.through(writeDocument, resolve));
    });    
  };

  return reformat;
}());